@@ -3,10 +3,10 @@
 #
 #   random (re)labelling
 #
-#   $Revision: 1.1 $   $Date: 2005/06/08 01:33:39 $
+#   $Revision: 1.2 $   $Date: 2006/10/10 04:22:48 $
 #
 #
-rlabel <- function(X, labels=X$marks, permute=TRUE) {
+rlabel <- function(X, labels=marks(X), permute=TRUE) {
   verifyclass(X, "ppp")
   if(is.null(labels))
     stop("labels not given and marks not present")
