@@ -1,13 +1,13 @@
 #
 # split.R
 #
-# $Revision: 1.4 $ $Date: 2006/02/25 02:17:22 $
+# $Revision: 1.6 $ $Date: 2006/10/10 04:22:48 $
 #
 # split.ppp and "split<-.ppp"
 #
 #########################################
 
-split.ppp <- function(x, f = x$marks, drop=FALSE, un=NULL, ...) {
+split.ppp <- function(x, f = marks(x), drop=FALSE, un=NULL, ...) {
   verifyclass(x, "ppp")
   if(is.null(un))
      un <- missing(f)
@@ -17,8 +17,8 @@ split.ppp <- function(x, f = x$marks, drop=FALSE, un=NULL, ...) {
     if(length(f) != x$n)
       stop("length(f) must equal the number of points in x")
   } else {
-    if(is.marked(x) && is.factor(x$marks)) 
-      f <- x$marks
+    if(is.multitype(x))
+      f <- marks(x)
     else
       stop("f is missing and there is no sensible default")
   }
@@ -34,16 +34,19 @@ split.ppp <- function(x, f = x$marks, drop=FALSE, un=NULL, ...) {
   return(out)
 }
 
-"split<-.ppp" <- function(x, f=x$marks, drop=FALSE, un=missing(f), 
+"split<-.ppp" <- function(x, f=marks(x), drop=FALSE, un=missing(f), 
                           ..., value) {
   verifyclass(x, "ppp")
   stopifnot(is.list(value))
   if(!all(unlist(lapply(value, is.ppp))))
-    stop("Each entry of \`value\' must be a point pattern")
+    stop(paste("Each entry of", sQuote("value"),
+               "must be a point pattern"))
 
   ismark <- unlist(lapply(value, is.marked))
   if(any(ismark) && !all(ismark))
-    stop("Some entries of \`value\' are marked, and others are unmarked")
+    stop(paste("Some entries of",
+               sQuote("value"),
+               "are marked, and others are unmarked"))
   vmarked <- all(ismark)
 
   # evaluate `un' before assigning value of 'f'
@@ -55,8 +58,8 @@ split.ppp <- function(x, f = x$marks, drop=FALSE, un=NULL, ...) {
     if(length(f) != x$n)
       stop("length(f) must equal the number of points in x")
   } else {
-    if(is.marked(x) && is.factor(x$marks))
-      f <- x$marks
+    if(is.multitype(x))
+      f <- marks(x)
     else
       stop("f is missing and there is no sensible default")
   }
@@ -68,13 +71,14 @@ split.ppp <- function(x, f = x$marks, drop=FALSE, un=NULL, ...) {
     levtype <- "levels which f actually takes"
   }
   if(length(value) != length(lev))
-      stop(paste("length of \`value\' should equal the number of",
+      stop(paste("length of", sQuote("value"),
+                 "should equal the number of",
                  levtype))
 
   # ensure value[[i]] is associated with lev[i]
   if(!is.null(names(value))) {
     if(!all(names(value) %in% paste(levels(f))))
-      stop("names of \`value\' should be levels of f")
+      stop(paste("names of", sQuote("value"), "should be levels of f"))
     value <- value[lev]
   }
   names(value) <- NULL
@@ -82,8 +86,8 @@ split.ppp <- function(x, f = x$marks, drop=FALSE, un=NULL, ...) {
   # restore the marks, if they were discarded
   if(un && is.marked(x)) {
     if(vmarked)
-      warning("\`value\' contains marked point patterns:\
- this is inconsistent with un=TRUE; marks ignored.")
+      warning(paste(sQuote("value"), "contains marked point patterns:",
+                    "this is inconsistent with un=TRUE; marks ignored."))
     for(i in seq(value)) 
       value[[i]] <- value[[i]] %mark% factor(lev[i], levels=levels(f))
   }
